﻿// Copyright (C) 2022 GlavSoft LLC.
// All rights reserved.
//


using System.Diagnostics;
using System.Windows.Forms;
using GlavSoft.RemoteCoreSDK.Viewer.Input;
using GlavSoft.RemoteCoreSDK.Viewer.Input.Keyboard;

// ReSharper disable once CheckNamespace
namespace GlavSoft.RemoteCoreSDK.Viewer.Demo.Input
{
    /// <summary>
    /// The KeyController for Win Forms Control. It inherits from <see cref="KeyboardControllerBase"/>
    /// and it contains specific methods for handling WinForms keyboard events.
    /// </summary>
    public class KeyboardController : KeyboardControllerBase
    {
        /// <summary>
        /// Initialize an entitity of <see cref="KeyboardController"/>
        /// </summary>
        /// <param name="sender"></param>
        public KeyboardController(IRFBKeyEventsSender sender) : base(sender)
        {
        }

        /// <summary>
        /// Handler for KeyDown event.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public async void KeyDownHandler(object sender, KeyEventArgs e)
        {
            Debug.Print("\nKeyDownHandler Event raised. KeyCode:" + e.KeyCode);
            await SendKeyEventAsync((int) e.KeyCode, true);
            e.Handled = true;
        }

        /// <summary>
        /// Handler for KeyUp event.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public async void KeyUpHandler(object sender, KeyEventArgs e)
        {
            Debug.Print("\nKeyUpHandler Event raised. KeyCode:" + e.KeyCode);
            await SendKeyEventAsync((int) e.KeyCode, false);
            e.Handled = true;
        }

        /// <summary>
        /// Handler for Key Press event.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="args"></param>
        public async void KeyPressHandler(object sender, KeyPressEventArgs args)
        {
            Debug.Print("\nKeyPressHandler Event raised. Args.KeyChar:" + args.KeyChar);
            await SendCharEventAsync(args.KeyChar).ConfigureAwait(false);
            args.Handled = true;
        }
    }
}