﻿// Copyright (C) 2022 GlavSoft LLC.
// All rights reserved.
//


using System.Text;

namespace GlavSoft.RemoteCoreSDK.Viewer.Demo
{
    /// <summary>
    /// You can use this class for logging of ViewerCore internals.
    /// One needs to pass instance of it to the constructor of ViewerCore.
    /// </summary>
    public class SimpleLogger : ILogger
    {
        private readonly LogLevel _acceptedLogLevel;

        public SimpleLogger(LogLevel acceptedLogLevel)
        {
            _acceptedLogLevel = acceptedLogLevel;
        }
        private string GetMsg(string message, LogMetaInformation info, LogLevel level)
        {
            var mainMsg = string.Format("{0,-20}|{1,-5}|{2}", info.SrcName, level, message);
            var sb = new StringBuilder(mainMsg);

            if (info.Exception != null)
            {
                sb.AppendLine(info.Exception.ToString());
            }

            return sb.ToString();
        }

        public void Trace(string message, LogMetaInformation info)
        {
            var msg = GetMsg(message, info, LogLevel.Trace);
            System.Diagnostics.Debug.Print(msg);
        }

        public void Debug(string message, LogMetaInformation info)
        {
            var msg = GetMsg(message, info, LogLevel.Debug);
            System.Diagnostics.Debug.Print(msg);
        }

        public void Info(string message, LogMetaInformation info)
        {
            var msg = GetMsg(message, info, LogLevel.Info);
            System.Diagnostics.Debug.Print(msg);
        }

        public void Warn(string message, LogMetaInformation info)
        {
            var msg = GetMsg(message, info, LogLevel.Warn);
            System.Diagnostics.Debug.Print(msg);
        }

        public void Error(string message, LogMetaInformation info)
        {
            var msg = GetMsg(message, info, LogLevel.Error);
            System.Diagnostics.Debug.Print(msg);
        }

        public void Fatal(string message, LogMetaInformation info)
        {
            var msg = GetMsg(message, info, LogLevel.Fatal);
            System.Diagnostics.Debug.Print(msg);
        }

        public LogLevel GetAcceptableLevel()
        {
            return _acceptedLogLevel;
        }
    }
}