﻿// Copyright (C) 2022 GlavSoft LLC.
// All rights reserved.
//
// DO NOT USE OR REDISTRIBUTE THE CODE, UNLESS YOU HAVE OBTAINED A LICENSE.
//

using NLog;
using NLog.Targets;
using NLog.Targets.Wrappers;

namespace GlavSoft.RemoteCoreSDK.Viewer.Demo.Configuration
{
    static class LoggingConfiguration
    {
        public static void UseDefault()
        {
            LogManager.Configuration = GetDefaultConfiguration();
        }

        /// <summary>
        /// Gets default configuration which writes log to file 
        /// </summary>
        /// <returns></returns>
        private static NLog.Config.LoggingConfiguration GetDefaultConfiguration()
        {
            var config = new NLog.Config.LoggingConfiguration();

            const string exceptionStr =
                @"${onexception:${newline}${exception:format=ToString:maxInnerExceptionLevel=2:innerFormat=ToString}}";
            const string timeStr = @"${time:universalTime=True}";
            const string levelStr = @"${pad:padding=-5:inner=${level}}";
            const string loggerStr = @"${pad:padding=-22:inner=${logger}}";
            const string threadIdStr = @"${pad:padding=-3:inner=${threadid}}";
            const string headerLayout =
                @"------------------------------"
                + @"${newline}Process:    ${processname}"
                + @"${newline}Version:    ${assembly-version}"
                + @"${newline}Start time: ${processinfo:property=StartTime}"
                + @"${newline}Machine:    ${windows-identity}"
                + @"${newline}------------------------------${newline}";
            const string footerLayout = "----------Logging finished on ${time:universalTime=True}-----------\n";

            var fileTarget = new FileTarget
            {
                Name = "file",
                FileName = "${basedir}/logs/${shortdate:universalTime=True}.log",
                Header = headerLayout,
                Footer = footerLayout,
                KeepFileOpen = true,
                Layout = $"{timeStr} | {threadIdStr} | {levelStr} | {loggerStr} | ${{message}} {exceptionStr}",
                ConcurrentWrites = false
            };

            var wrapper = new AsyncTargetWrapper
            {
                WrappedTarget = fileTarget,
                QueueLimit = 5000,
                OverflowAction = AsyncTargetWrapperOverflowAction.Block
            };

            config.AddRule(NLog.LogLevel.Trace, NLog.LogLevel.Fatal, wrapper);
            return config;
        }
    }
}