﻿// Copyright (C) 2022 GlavSoft LLC.
// All rights reserved.
//
// DO NOT USE OR REDISTRIBUTE THE CODE, UNLESS YOU HAVE OBTAINED A LICENSE.
//

using System.ComponentModel;
using System.Windows;
using GlavSoft.RemoteCoreSDK;
using GlavSoft.RemoteCoreSDK.Extensions.Loggers.NLog;
using GlavSoft.RemoteCoreSDK.Viewer.Demo.Configuration;
using GlavSoft.RemoteCoreSDK.Viewer.WPF;
using GlavSoft.RemoteCoreSDK.Viewer.WPF.Demo;
using LogLevel = GlavSoft.RemoteCoreSDK.LogLevel;

namespace WPF.Demo
{
    /// <summary>
    /// Interaction logic for Settings.xaml
    /// </summary>
    public partial class Settings
    {
        private bool _isShownAttentionMsg;
        private ILogger _logger;
        private bool _isDiagnosticFirstChange = true;

        public Settings(RemoteDesktopControl control, ILogger logger = null)
        {
            InitializeComponent();

            DesktopControl = control;

            _logger = logger;
            if (_logger != null)
            {
                DiagnosticMode = true;
            }
        }

        public RemoteDesktopControl DesktopControl { get; set; }

        protected override void OnClosing(CancelEventArgs e)
        {
            e.Cancel = true;
            Owner?.Focus();
            Hide();
        }

        private void OnCloseClick(object sender, RoutedEventArgs e)
        {
            Owner?.Focus();
            Hide();
        }

        public static readonly DependencyProperty DiagnosticModeProperty = DependencyProperty.Register("DiagnosticMode",
            typeof(bool), typeof(Settings), new PropertyMetadata(false, DiagnosticModePropertyChanged));

        private static void DiagnosticModePropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var settingsWindow = (Settings)d;

            if (settingsWindow._logger != null && settingsWindow._isDiagnosticFirstChange)
            {
                settingsWindow._isDiagnosticFirstChange = false;
                return;
            }

            var isEnabled = (bool)e.NewValue;
            var mainWindow = (MainWindow)settingsWindow.Owner;
            if (isEnabled)
            {
                settingsWindow._isDiagnosticFirstChange = false;

                if (settingsWindow._logger == null)
                {
                    LoggingConfiguration.UseDefault();
                    settingsWindow._logger = new NLogLogger(LogLevel.Trace);
                }

                settingsWindow.DesktopControl.SetLogger(settingsWindow._logger);
                if (!settingsWindow._isShownAttentionMsg)
                {
                    MessageBox.Show(settingsWindow,
                        "The Diagnostic mode can affect the image quality and responsiveness",
                        "Attention", MessageBoxButton.OK, MessageBoxImage.Warning);
                    settingsWindow._isShownAttentionMsg = true;
                }

                mainWindow.DiagnosticMode = true;
            }
            else
            {
                settingsWindow.DesktopControl.SetLogger(null);

                mainWindow.DiagnosticMode = false;
            }

            settingsWindow.Focus();
        }

        public bool DiagnosticMode
        {
            get => (bool)GetValue(DiagnosticModeProperty);
            set => SetValue(DiagnosticModeProperty, value);
        }
    }
}