﻿// Copyright (C) 2022 GlavSoft LLC.
// All rights reserved.
//
// DO NOT USE OR REDISTRIBUTE THE CODE, UNLESS YOU HAVE OBTAINED A LICENSE.
//

using System;
using System.Diagnostics;
using System.IO;
using GlavSoft.Viewer.WinForms.Configuration;

namespace GlavSoft.Viewer.WinForms.Demo.Configuration
{
    class ConfigurationProvider
    {
        public static ViewerConfiguration ReadConfiguration()
        {
            var defaultResult = new ViewerConfiguration();
            try
            {
                var path = Path.Combine(Environment.GetFolderPath(
                    Environment.SpecialFolder.ApplicationData), "GlavSoft\\Demo\\winformsConfig.json");

                if (!File.Exists(path))
                {
                    return defaultResult;
                }
                var rawString = File.ReadAllText(path);

                var viewerConfiguration = JsonSerializer.Instance.Deserialize<ViewerConfiguration>(rawString);

                return viewerConfiguration;
            }
            catch (Exception e)
            {
                Debug.Write(e);
                return defaultResult;
            }
        }

        public static void SaveConfiguration(ViewerConfiguration config)
        {
            try
            {
                var path = Path.Combine(Environment.GetFolderPath(
                    Environment.SpecialFolder.ApplicationData), "GlavSoft\\Demo\\winformsConfig.json");
                var directoryName = Path.GetDirectoryName(path);
                if (!Directory.Exists(directoryName))
                {
                    // ReSharper disable once AssignNullToNotNullAttribute
                    Directory.CreateDirectory(directoryName);
                }

                var str = JsonSerializer.Instance.Serialize(config);

                File.WriteAllText(path, str);
            }
            catch (Exception e)
            {
                Debug.Write(e);
            }
        }
    }
}